Get class
An annotation for HTTP GET requests.
GET requests are used for retrieving data from the server without causing any side effects. They should be idempotent and safe.
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- path → String
-
The endpoint path for this HTTP request.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
validateStatus
→ List<
int> -
A list of HTTP status codes that should be considered successful.
finalinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited